[PATCH] gpio: samsung: remove exynos_gpio_cfg

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



The exynos_gpio_cfg can be substituted to samsung_gpio_cfgs[8].

Signed-off-by: Joonyoung Shim <jy0922.shim@xxxxxxxxxxx>
---
 drivers/gpio/gpio-samsung.c |   25 ++++++++-----------------
 1 file changed, 8 insertions(+), 17 deletions(-)

diff --git a/drivers/gpio/gpio-samsung.c b/drivers/gpio/gpio-samsung.c
index 6f93d36..a462f2c 100644
--- a/drivers/gpio/gpio-samsung.c
+++ b/drivers/gpio/gpio-samsung.c
@@ -452,15 +452,6 @@ static struct samsung_gpio_cfg s3c24xx_gpiocfg_banka = {
 };
 #endif
 
-#if defined(CONFIG_ARCH_EXYNOS4) || defined(CONFIG_ARCH_EXYNOS5)
-static struct samsung_gpio_cfg exynos_gpio_cfg = {
-	.set_pull	= exynos_gpio_setpull,
-	.get_pull	= exynos_gpio_getpull,
-	.set_config	= samsung_gpio_setcfg_4bit,
-	.get_config	= samsung_gpio_getcfg_4bit,
-};
-#endif
-
 #if defined(CONFIG_CPU_S5P6440) || defined(CONFIG_CPU_S5P6450)
 static struct samsung_gpio_cfg s5p64x0_gpio_cfg_rbank = {
 	.cfg_eint	= 0x3,
@@ -2181,7 +2172,7 @@ static struct samsung_gpio_chip s5pv210_gpios_4bit[] = {
  * Followings are the gpio banks in EXYNOS SoCs
  *
  * The 'config' member when left to NULL, is initialized to the default
  * structure exynos_gpio_cfg in the init function below.
  *
  * The 'base' member is also initialized in the init function below.
  * Note: The initialization of 'base' member of samsung_gpio_chip structure
@@ -2837,7 +2828,7 @@ static __init void exynos4_gpiolib_init(void)
 
 	for (i = 0; i < nr_chips; i++, chip++) {
 		if (!chip->config) {
-			chip->config = &exynos_gpio_cfg;
+			chip->config = &samsung_gpio_cfgs[8];
 			chip->group = group++;
 		}
 		exynos_gpiolib_attach_ofnode(chip,
@@ -2864,7 +2855,7 @@ static __init void exynos4_gpiolib_init(void)
 
 	for (i = 0; i < nr_chips; i++, chip++) {
 		if (!chip->config) {
-			chip->config = &exynos_gpio_cfg;
+			chip->config = &samsung_gpio_cfgs[8];
 			chip->group = group++;
 		}
 		exynos_gpiolib_attach_ofnode(chip,
@@ -2885,7 +2876,7 @@ static __init void exynos4_gpiolib_init(void)
 
 	for (i = 0; i < nr_chips; i++, chip++) {
 		if (!chip->config) {
-			chip->config = &exynos_gpio_cfg;
+			chip->config = &samsung_gpio_cfgs[8];
 			chip->group = group++;
 		}
 		exynos_gpiolib_attach_ofnode(chip,
@@ -2940,7 +2931,7 @@ static __init void exynos5_gpiolib_init(void)
 
 	for (i = 0; i < nr_chips; i++, chip++) {
 		if (!chip->config) {
-			chip->config = &exynos_gpio_cfg;
+			chip->config = &samsung_gpio_cfgs[8];
 			chip->group = group++;
 		}
 		exynos_gpiolib_attach_ofnode(chip,
@@ -2961,7 +2952,7 @@ static __init void exynos5_gpiolib_init(void)
 
 	for (i = 0; i < nr_chips; i++, chip++) {
 		if (!chip->config) {
-			chip->config = &exynos_gpio_cfg;
+			chip->config = &samsung_gpio_cfgs[8];
 			chip->group = group++;
 		}
 		exynos_gpiolib_attach_ofnode(chip,
@@ -2989,7 +2980,7 @@ static __init void exynos5_gpiolib_init(void)
 
 	for (i = 0; i < nr_chips; i++, chip++) {
 		if (!chip->config) {
-			chip->config = &exynos_gpio_cfg;
+			chip->config = &samsung_gpio_cfgs[8];
 			chip->group = group++;
 		}
 		exynos_gpiolib_attach_ofnode(chip,
@@ -3010,7 +3001,7 @@ static __init void exynos5_gpiolib_init(void)
 
 	for (i = 0; i < nr_chips; i++, chip++) {
 		if (!chip->config) {
-			chip->config = &exynos_gpio_cfg;
+			chip->config = &samsung_gpio_cfgs[8];
 			chip->group = group++;
 		}
 		exynos_gpiolib_attach_ofnode(chip,
@@ -2181,7 +2172,7 @@ static struct samsung_gpio_chip s5pv210_gpios_4bit[] = {
  *
  * The 'config' member when left to NULL, is initialized to the default
- * structure exynos_gpio_cfg in the init function below.
+ * structure samsung_gpio_cfgs[8] in the init function below.
  *
  * The 'base' member is also initialized in the init function below.
-- 
1.7.9.5

--
To unsubscribe from this list: send the line "unsubscribe linux-samsung-soc" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[Index of Archives]     [Linux SoC Development]     [Linux Rockchip Development]     [Linux USB Development]     [Video for Linux]     [Linux Audio Users]     [Linux SCSI]     [Yosemite News]

  Powered by Linux